pub struct InMemoryWorkItemStateStore<W>where
W: WorkItem,{ /* private fields */ }Trait Implementations
Sourceimpl<W> Clone for InMemoryWorkItemStateStore<W>
impl<W> Clone for InMemoryWorkItemStateStore<W>
Sourcefn clone(&self) -> InMemoryWorkItemStateStore<W>
fn clone(&self) -> InMemoryWorkItemStateStore<W>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<W> Debug for InMemoryWorkItemStateStore<W>
impl<W> Debug for InMemoryWorkItemStateStore<W>
Sourceimpl<W> Default for InMemoryWorkItemStateStore<W>where
W: WorkItem,
impl<W> Default for InMemoryWorkItemStateStore<W>where
W: WorkItem,
Sourcefn default() -> InMemoryWorkItemStateStore<W>
fn default() -> InMemoryWorkItemStateStore<W>
Returns the “default value” for a type. Read more
Sourceimpl<W> WorkItemStateStore<W> for InMemoryWorkItemStateStore<W>where
W: WorkItem,
impl<W> WorkItemStateStore<W> for InMemoryWorkItemStateStore<W>where
W: WorkItem,
Sourcefn get_status<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<WorkItemStatus, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
fn get_status<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<WorkItemStatus, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
Get the status of a work item.
Sourcefn set_status<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
status: WorkItemStatus,
) -> Pin<Box<dyn Future<Output = Result<(), WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
fn set_status<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
status: WorkItemStatus,
) -> Pin<Box<dyn Future<Output = Result<(), WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
Set the status of a work item.
Sourcefn get_attempts<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<u32, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
fn get_attempts<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<u32, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
Get the number of attempts for a work item.
Sourcefn increment_attempts<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<u32, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
fn increment_attempts<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<u32, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
Increment the number of attempts for a work item.
Sourcefn reset_attempts<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<(), WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
fn reset_attempts<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
item: &'life2 W,
) -> Pin<Box<dyn Future<Output = Result<(), WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
Reset the number of attempts for a work item.
Sourcefn get_all<'life0, 'life1, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<WorkItemState<W>>, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
fn get_all<'life0, 'life1, 'async_trait>(
&'life0 self,
run_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<WorkItemState<W>>, WorkItemStateStoreError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
InMemoryWorkItemStateStore<W>: 'async_trait,
Get all work items for a run.